@@ -111,6 +111,7 @@ class Connection:
         assert self._conn.isexecuting(), "Is conn an async at all???"
         self._fileno = self._conn.fileno()
         self._timeout = timeout
+        self._last_usage = self._loop.time()
         self._waiter = waiter
         self._writing = False
         self._cancelling = False
@@ -264,6 +265,7 @@ class Connection:
         psycopg in asynchronous mode.
 
         """
+        self._last_usage = self._loop.time()
         coro = self._cursor(name=name, cursor_factory=cursor_factory,
                             scrollable=scrollable, withhold=withhold,
                             timeout=timeout)
@@ -492,6 +494,11 @@ class Connection:
         """Return default timeout for connection operations."""
         return self._timeout
 
+    @property
+    def last_usage(self):
+        """Return time() when connection was used."""
+        return self._last_usage
+
     @property
     def echo(self):
         """Return echo mode status."""
