@@ -1,8 +1,8 @@
 import asyncio
 
 from sqlalchemy.sql import ClauseElement
-from sqlalchemy.sql.dml import UpdateBase
 from sqlalchemy.sql.ddl import DDLElement
+from sqlalchemy.sql.dml import UpdateBase
 
 from . import exc
 from .result import ResultProxy
@@ -12,7 +12,6 @@ from ..utils import _SAConnectionContextManager, _TransactionContextManager
 
 
 class SAConnection:
-
     def __init__(self, connection, engine):
         self._connection = connection
         self._transaction = None
@@ -69,6 +68,8 @@ class SAConnection:
         elif dp:
             dp = dp[0]
 
+        result_map = None
+
         if isinstance(query, str):
             yield from cursor.execute(query, dp)
         elif isinstance(query, ClauseElement):
@@ -83,8 +84,8 @@ class SAConnection:
                         raise exc.ArgumentError("Don't mix sqlalchemy SELECT "
                                                 "clause with positional "
                                                 "parameters")
-                compiled_parameters = [compiled.construct_params(
-                    dp)]
+
+                compiled_parameters = [compiled.construct_params(dp)]
                 processed_parameters = []
                 processors = compiled._bind_processors
                 for compiled_params in compiled_parameters:
@@ -95,18 +96,24 @@ class SAConnection:
                     processed_parameters.append(params)
                 post_processed_params = self._dialect.execute_sequence_format(
                     processed_parameters)
+
+                # _result_columns is a private API of Compiled,
+                # but I couldn't find any public API exposing this data.
+                result_map = compiled._result_columns
+
             else:
                 if dp:
                     raise exc.ArgumentError("Don't mix sqlalchemy DDL clause "
                                             "and execution with parameters")
                 post_processed_params = [compiled.construct_params()]
+                result_map = None
             yield from cursor.execute(str(compiled), post_processed_params[0])
         else:
             raise exc.ArgumentError("sql statement should be str or "
                                     "SQLAlchemy data "
                                     "selection/modification clause")
 
-        return ResultProxy(self, cursor, self._dialect)
+        return ResultProxy(self, cursor, self._dialect, result_map)
 
     @asyncio.coroutine
     def scalar(self, query, *multiparams, **params):
@@ -192,7 +199,6 @@ class SAConnection:
             cur.close()
             self._transaction = None
 
-    @asyncio.coroutine
     def begin_nested(self):
         """Begin a nested transaction and return a transaction handle.
 
@@ -204,6 +210,11 @@ class SAConnection:
         still controls the overall .commit() or .rollback() of the
         transaction of a whole.
         """
+        coro = self._begin_nested()
+        return _TransactionContextManager(coro)
+
+    @asyncio.coroutine
+    def _begin_nested(self):
         if self._transaction is None:
             self._transaction = RootTransaction(self)
             yield from self._begin_impl()
